@@ -1,5 +1,7 @@
 from enum import Enum
 
+from .candle_data import CandleData, OutdatedUpdateError
+
 
 class Intervals(Enum):
     MINS1 = "1m"
@@ -20,6 +22,3 @@ class Intervals(Enum):
 
     def __str__(self):
         return self.value
-
-    def __repr__(self):
-        return self.value
